**Example 1: 查询网络攻击设置**

查询网络攻击设置

Input: 

```
tccli cwp DescribeNetAttackSetting --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "NetAttackAlarmStatus": 0,
        "NetAttackEnable": 1,
        "RequestId": "8c1f7156-fc01-4905-b286-e08f4db0eec2"
    }
}
```

